@@ -3,6 +3,7 @@ import collections
 import getpass
 import math
 import os
+import os.path
 import subprocess
 import sys
 import textwrap
@@ -140,7 +141,7 @@ class BaseScheduler(metaclass=_RequireAttrsABCMeta):
 
     def batch_fname(self, name: str) -> str:
         """The filename of the job script."""
-        return name + self.ext
+        return os.path.abspath(name + self.ext)
 
     @staticmethod
     def sanatize_job_id(job_id):
